<?php

namespace App\Form\Type;

use App\Entity\SelfEvalPrestaQuiz;
use Symfony\Component\Form\AbstractType;
use Symfony\Component\Form\Extension\Core\Type\ChoiceType;
use Symfony\Component\Form\Extension\Core\Type\SubmitType;
use Symfony\Component\Form\Extension\Core\Type\TextareaType;
use Symfony\Component\Form\FormBuilderInterface;
use Symfony\Component\OptionsResolver\OptionsResolver;
use Symfony\Component\Validator\Constraints\NotNull;

/**
 *
 * Self-eval prestataire questionnaire base class
 * containing useful attributes and buildForm for
 * sections that are common to distributors and producers
 */
class SelfEvalPrestaQuizType extends AbstractType
{
    protected array $stdChoices;
    protected array $opts;
    protected array $cmtOpts;
    protected string $labelEvalGlob;
    protected string $frown;
    protected string $meh;
    protected string $smile;

    public function __construct()
    {
        $this->frown = '<i class="fas fa-frown text-danger"></i>';
        $this->meh = '<i class="fas fa-meh text-warning"></i>';
        $this->smile = '<i class="fas fa-smile text-success"></i>';

        $this->stdChoices = [
            $this->frown . ' non' => 0,
            $this->meh . ' moyennement' => 1,
            $this->smile . ' oui' => 2,
        ];
        $this->stdGlobalChoices = [
            $this->frown => 0,
            $this->meh => 1,
            $this->smile => 2,
        ];
        $this->opts = [
            'label' => '',
            'choices' => $this->stdChoices,
            'expanded' => true,
            "multiple" => false,
            'constraints' => [new NotNull()],
        ];
        $this->cmtOpts = [
            'attr' => ['placeholder' => 'Commentaires'],
            'label' => false,
            'required' => false,
        ];
        $this->labelEvalGlob = "évaluation globale";
    }

    public function buildForm(FormBuilderInterface $builder, array $options)
    {
        /* PARTIE 1 : ACCESSIBILITE ET INCLUSIVITE */
        $this->opts['label'] = "Géographique et physique : le lieu est-il accessible par différents modes de transport ?";
        $this->opts['choices'] = [
            $this->frown . " 0 mode de transport" => 0,
            $this->meh . " 1 mode de transport" => 1,
            $this->smile . " plus d'1 mode de transport" => 2,
        ];
        $builder->add('accessib_geophy', ChoiceType::class, $this->opts);
        $builder->add('accessib_geophy_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Temporelle : le lieu communique-t-il sur ses plages d'ouvertures ?";
        $this->opts['choices'] = [
            $this->frown . " 0 mode de communication" => 0,
            $this->meh . " 1 mode de communication" => 1,
            $this->smile . " plus d'1 mode de communication" => 2,
        ];
        $builder->add('accessib_tempor', ChoiceType::class, $this->opts);
        $builder->add('accessib_tempor_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Sociale et inclusivité (1/3) : le lieu mène-t-il des actions de sensibilisation et d'éducation populaire à l'alimentation ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('accessib_edupop', ChoiceType::class, $this->opts);
        $builder->add('accessib_edupop_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Sociale et inclusivité (2/3) : le lieu propose-t-il des services spécifiques pour faciliter son accessibilité à une diversité
                de profils (pour les personnes agées, les personnes en situation de handicap, les familles ...) ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('accessib_divers', ChoiceType::class, $this->opts);
        $builder->add('accessib_divers_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Sociale et inclusivité (3/3) : le lieu mène-t-il des actions spécifiques pour lutter contre la vulnérabilité alimentaire ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('accessib_vulner', ChoiceType::class, $this->opts);
        $builder->add('accessib_vulner_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Accessibilité et inclusivité : " . $this->labelEvalGlob;
        $this->opts['choices'] = $this->stdGlobalChoices;
        $builder->add('accessib_global', ChoiceType::class, $this->opts);
        $builder->add('accessib_global_comment', TextareaType::class, $this->cmtOpts);

        /* PARTIE 2 : BIEN-ETRE AU TRAVAIL */
        $this->opts['label'] = "Le lieu met-il en place des actions pour faciliter l'accueil, l'intégration et la formation des personnes qui y travaillent ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('bienetre_format', ChoiceType::class, $this->opts);
        $builder->add('bienetre_format_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Les travailleurs sont-ils impliqués dans la gouvernance ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('bienetre_impgou', ChoiceType::class, $this->opts);
        $builder->add('bienetre_impgou_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Le lieu met-il en place des actions pour améliorer le bien-être des personnes qui y travaillent ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('bienetre_bienet', ChoiceType::class, $this->opts);
        $builder->add('bienetre_bienet_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Le lieu met-il en place des actions pour valoriser et reconnaître le travail fourni par les bénévoles ?";
        $this->opts['choices'] = $this->stdChoices;
        $builder->add('bienetre_recben', ChoiceType::class, $this->opts);
        $builder->add('bienetre_recben_comment', TextareaType::class, $this->cmtOpts);
        $this->opts['label'] = "Bien-être au travail : " . $this->labelEvalGlob;
        $this->opts['choices'] = $this->stdGlobalChoices;
        $builder->add('bienetre_global', ChoiceType::class, $this->opts);
        $builder->add('bienetre_global_comment', TextareaType::class, $this->cmtOpts);

        $builder->add('save', SubmitType::class, ['label' => 'Envoyer'])
        ;
    }

    /**
     *
     */
    public function configureOptions(OptionsResolver $resolver)
    {
        $resolver->setDefaults([
            'data_class' => SelfEvalPrestaQuiz::class,
        ]);
    }

    public function getBlockPrefix(): string
    {
        return 'formSelfEvalPrestaQuiz';
    }
}
